@@ -475,6 +475,7 @@ void Kwappen::paintEvent(QPaintEvent*)              // paint event
             turm_reduce(); break;
     case 7: swap = 0;
             swapbutton->setText(i18n("Swap stone 1x"));  // end check
+            swapbutton->setEnabled(true);
             ende_check(); break;
     case 8: status = 10;                           // you lose
             break;
@@ -639,6 +640,7 @@ void Kwappen::swapComp()                           // swap computer stone (max.
     }
     swap = 1;
     swapbutton->setText(i18n("disabled"));        // disable swap button
+    swapbutton->setEnabled(false);                // button grey
     repaint(); return;
   }
 }
@@ -938,7 +940,7 @@ void Heraldry::closeHeraldry()
 void Kwappen::topWA(KApplication* app)                  // menu entries
 {
   menu = new KMenuBar(topW);
-  datei = new QPopupMenu();
+  datei = new KPopupMenu();
   menu->insertItem(i18n("Game  "), datei);
   datei->insertItem(i18n("New game"), topW, SLOT(newGame()), Qt::CTRL + Qt::Key_N);
   datei->insertSeparator();
@@ -947,7 +949,7 @@ void Kwappen::topWA(KApplication* app)                  // menu entries
   datei->insertItem(i18n("Clear highscore"), topW, SLOT(clearHighscore()), Qt::ALT + Qt::Key_C);
   datei->insertSeparator();
   datei->insertItem(i18n("Quit"), app, SLOT(quit()), Qt::CTRL + Qt::Key_Q);
-  options = new QPopupMenu();
+  options = new KPopupMenu();
   menu->insertItem(i18n("Options  "), options);
   autoshitem = options->insertItem(i18n("Autoshrink delay"), topW, SLOT(autoShrink()), Qt::CTRL + Qt::Key_A);
   options->insertSeparator();
@@ -956,9 +958,15 @@ void Kwappen::topWA(KApplication* app)                  // menu entries
   options->insertItem(i18n("Swap stone 1x"), topW, SLOT(swapComp()), Qt::Key_Space);
   options->insertSeparator();
   options->insertItem(i18n("Heraldry"), topW, SLOT(heraldry()), Qt::CTRL + Qt::Key_H);
-  help = new QPopupMenu();
+
+  KPopupMenu *help = helpMenu(QString(i18n("KWappen"))
+           + " " + VERSION
+           + "\n\nWritten by Jens Schulz 2002  GPL2"
+           + "\n(jschulz-lcs@t-online.de)"
+           + "\n\nhttp://www.lcs-chemie.de");
+
   if (auto_sh_delay) options->setItemChecked(autoshitem,TRUE);
   else options->setItemChecked(autoshitem,FALSE);
-  menu->insertItem(i18n("Help  "), helpMenu());
+  menu->insertItem(i18n("Help  "), help);
   menu->show();
 }
