@@ -32,6 +32,7 @@
 #include <kapp.h>
 #include <kmainwindow.h>
 #include <kmenubar.h>
+#include <kpopupmenu.h>
 #include <klocale.h>
 #include <kcmdlineargs.h>
 #include <kstdaction.h>
@@ -109,9 +110,8 @@ class Kwappen : public KMainWindow
   int sekunden;
 
   KMenuBar* menu;
-  QPopupMenu* datei;
-  QPopupMenu* options;
-  QPopupMenu* help;
+  KPopupMenu* datei;
+  KPopupMenu* options;
   QPushButton* swapbutton;
   QPushButton* rotatebutton1;
   QPushButton* rotatebutton2;
